@@ -2,9 +2,10 @@ import os
 import json
 import shutil
 import requests
-from pathlib import Path
+# from pathlib import Path
 
-from .trace import MANAGE, REQUIREMENTS, WSGI, URLS, SETTINGS, VIEWS, MODELS, ADMIN, README, APP_URLS
+# URLS, REQUIREMENTS, README, ADMIN
+from .trace import MANAGE, WSGI, SETTINGS, BASE_SETTINGS, VIEWS, BASE_MODELS, APP_URLS
 
 
 def generate(terminal_token, project_token, *args):
@@ -15,7 +16,6 @@ def generate(terminal_token, project_token, *args):
             'project_token': project_token,
         })).json()
 
-        secret_key = res.get('misc').get('secret_key')
         project_name = res.get('misc').get('project_name')
         working_dir = os.getcwd() + '/' + args[0] + '/' + project_name + '/' if args[0] else os.getcwd() + '/' + project_name + '/'
         
@@ -26,8 +26,9 @@ def generate(terminal_token, project_token, *args):
         
         base_file_tree = {
             'manage.py': MANAGE(project_name),
-            project_name + '/': [('__init__.py', ''), ('wsgi.py', WSGI(project_name)), ('settings.py', SETTINGS(project_name, res.get('apps'), res.get('settings'), secret_key)), ('urls.py', URLS(res.get('apps')))],
+            project_name + '/': [('__init__.py', ''), ('wsgi.py', WSGI(project_name)), ('settings.py', SETTINGS(res.get('settings'),))],
         }
+            # , ('urls.py', URLS(res.get('apps')))
             # 'README.md': README(),
             # 'requirements.txt': REQUIREMENTS(),
             # 'db.sqlite3': '',
@@ -69,7 +70,7 @@ def generate(terminal_token, project_token, *args):
         raise Exception('base template error')
 
 
-# syncs usr/local/.clix/project_token folder
+# creates clixdev.__path__/apps/clix/*
 def sync(terminal_token, project_token, *args):
     res = requests.post('https://api.clix.dev/api/package/sync',
                         data=json.dumps({
@@ -103,7 +104,11 @@ def sync(terminal_token, project_token, *args):
     f.close()
 
     f = open(clixdev.__path__[0] + '/apps/clix' + '/models.py', 'w')
-    f.write(MODELS(res.get('apps')[0]))
+    f.write(BASE_MODELS(res.get('apps')[0]))
+    f.close()
+    
+    f = open(clixdev.__path__[0] + '/apps/clix' + '/settings.py', 'w')
+    f.write(BASE_SETTINGS(res.get('misc').get('project_name'), res.get('misc').get('secret_key')))
     f.close()
 
     f = open(clixdev.__path__[0] + '/apps/clix' + '/apps.py', 'w')
@@ -114,6 +119,15 @@ class AppConfig(AppConfig):
 """)
     f.close()
 
+    import clix
+    f = open(clix.__path__[0] + '/views.py', 'w')
+    lines = f.readlines()
+    for row in lines:
+        word = 'def X4D20C'
+        if row.find(word) == 0:
+            f.write(f"""@csrf_exempt\ndef X4D20C(request, *args, **kwargs):\n\tbody = json.loads(request.body)\n\treturn JsonResponse({{}})\n\n""")
+    f.close()
+
     # not sure about views yet
     # f = open('projects/' + '/_validators.txt', 'w')
     # f.write(json.dumps("""[{"name": "API", "base_url": "api", "endpoints": [{"misc": {"endpoint_id": "ae0937d9-95e4-4ea1-9ff5-76312209e948", "is_draft": false, "token": "rcxxday", "name": "Get all users", "description": "The description", "base_url": "api"}, "request": {"method": "GET", "host": "localhost", "uri": "users/all"}, "headers": {"authorization": true, "body": {"0": ["auth-token", "str"]}}, "params": {"0": ["d", "uuid"]}, "body": {"type": "none", "payload": {}}, "response": {"code": "200", "message": "OK"}}], "models": [{"table_name": "User", "fields": {"0": ["D372D1", "id", "UUIDField", null, null, false, false, false, true, true], "1": ["F8B9D7", "f_name", "CharField", null, null, true, true, true, false, false], "2": ["D0BA20", "l_name", "CharField", null, null, true, true, true, false, false], "3": ["21341C", "created_at", "DateTimeField", null, null, false, false, true, false, false]}}]}]"""))
