@@ -20,13 +20,8 @@ if __name__ == '__main__':
 \tmain()
 """
 
-
+# deprecated at beta
 def URLS(apps):
-    # routes = [f"from {app['name']} import urls as {app['name']}_urls\n" for app in apps]
-    # includes = []
-    # for app in apps:
-    #     includes.append(f"\tpath('{app['base_url']}', include({app['name']}_urls)),\n")
-
     return f"""from clixdev.apps.clix import urls
 from django.contrib import admin
 from django.urls import path, include
@@ -37,38 +32,17 @@ urlpatterns = [
 \tpath('api/', include(urls)),
 ]
 """
-# removed due to beta
-# {''.join(routes)}
-# {''.join(includes)}
 
 
-def SETTINGS(proj_name, apps, settings, secret_key):
-    settings = [setting[0]+ ' = ' + setting[1] + '\n' for setting in settings.values()]
-# \t{','.join("'" + app['name'] + "'" for app in apps)},
-    return f"""from pathlib import Path
-from datetime import timedelta
+def BASE_SETTINGS(proj_name, secret_key):
+    return f"""import {proj_name}
 
-# Build paths inside the project like this: BASE_DIR / 'subdir'.
-BASE_DIR = Path(__file__).resolve().parent.parent
+BASE_DIR = {proj_name}.__path__[0]
 
-
-# Quick-start development settings - unsuitable for production
-# See https://docs.djangoproject.com/en/3.1/howto/deployment/checklist/
-
-# SECURITY WARNING: keep the secret key used in production secret!
 SECRET_KEY = '{secret_key}'
 
-# SECURITY WARNING: don't run with debug turned on in production!
-DEBUG = True
-
 ALLOWED_HOSTS = []
 
-#### SETTINGS ####
-{''.join([setting for setting in settings])}
-
-
-# Application definition
-
 INSTALLED_APPS = [
 \t'django.contrib.admin',
 \t'django.contrib.auth',
@@ -90,12 +64,12 @@ MIDDLEWARE = [
 \t'clixdev.kit.middleware.Middleware'
 ]
 
-ROOT_URLCONF = '{proj_name}.urls'
+ROOT_URLCONF = 'clixdev.apps.clix.urls'
 
 TEMPLATES = [
 \t{{
 \t\t'BACKEND': 'django.template.backends.django.DjangoTemplates',
-\t\t'DIRS': [BASE_DIR / 'templates'],
+\t\t'DIRS': [],
 \t\t'APP_DIRS': True,
 \t\t'OPTIONS': {{
 \t\t\t'context_processors': [
@@ -110,22 +84,13 @@ TEMPLATES = [
 
 WSGI_APPLICATION = '{proj_name}.wsgi.application'
 
-
-# Database
-# https://docs.djangoproject.com/en/3.1/ref/settings/#databases
-
 DATABASES = {{
 \t'default': {{
 \t\t'ENGINE': 'django.db.backends.sqlite3',
-\t\t'NAME': BASE_DIR / 'db.sqlite3',
+\t\t'NAME': BASE_DIR + '/db.sqlite3',
 \t}}
 }}
 
-
-# Password validation
-# https://docs.djangoproject.com/en/3.1/ref/settings/#auth-password-validators
-
-
 AUTH_PASSWORD_VALIDATORS = [
 \t{{
 \t\t'NAME': 'django.contrib.auth.password_validation.UserAttributeSimilarityValidator',
@@ -141,10 +106,6 @@ AUTH_PASSWORD_VALIDATORS = [
 \t}},
 ]
 
-
-# Internationalization
-# https://docs.djangoproject.com/en/3.1/topics/i18n/
-
 LANGUAGE_CODE = 'en-us'
 
 TIME_ZONE = 'UTC'
@@ -155,13 +116,24 @@ USE_L10N = True
 
 USE_TZ = True
 
-
-# Static files (CSS, JavaScript, Images)
-# https://docs.djangoproject.com/en/3.1/howto/static-files/
-
 STATIC_URL = '/static/'
+"""
 
-    """
+
+def SETTINGS(settings):
+    settings = [setting[0]+ ' = ' + setting[1] + '\n' for setting in settings.values()]
+    return f"""from clixdev.apps.clix.settings import *
+
+DEBUG = True
+ALLOWED_HOSTS += []
+
+#### SETTINGS ####
+{''.join([setting for setting in settings])}
+
+
+INSTALLED_APPS += []
+MIDDLEWARE += []
+"""
 
 
 def WSGI(proj_name):
@@ -177,17 +149,17 @@ application = get_wsgi_application()
 
 def VIEWS(app):
     endpoints = app['endpoints']
-    defs = ["import json\nfrom django.http import JsonResponse\nfrom django.views.decorators.csrf import csrf_exempt\n\nfrom clixdev.apps.clix.models import *"]
+    defs = ["from django.http import JsonResponse\nfrom clixdev.apps.clix.models import *\nfrom django.views.decorators.csrf import csrf_exempt"]
 
     for endpoint in endpoints:
         misc = endpoint['misc']
         req = endpoint['request']
         response = endpoint.get('response')
-        responses = ''.join([f'"{k}": "{v}",' for k, v in response.items()])
+        responses = ''.join([f'"{k}": "{v}",' for k, v in response.items()]) if len(response.items()) > 0 else ''
         csrf = '@csrf_exempt\n' if req.get('host') == 'localhost' else ''
-        header_code = '\n\t\t\theaders = request.headers' if len(endpoint.get('headers').get('body').items()) > 0 else ''
-        param_code = '\n\t\t\tparams = kwargs.items()' if len(endpoint.get('params').items()) > 0 else ''
-        body_code = '\n\t\t\tbody = json.loads(request.body)\n\n' if len(endpoint.get('body').get('payload')) > 0 else '\n' if header_code != '' else ''
+        header_code = '\theaders = request.headers' if len(endpoint.get('headers').get('body').items()) > 0 else ''
+        params_code = '\n\tparams = kwargs.items()' if len(endpoint.get('params').items()) > 0 and header_code != '' else '\tparams = kwargs.items()' if len(endpoint.get('params').items()) > 0 and header_code == '' else ''
+        body_code = '\n\tbody = json.loads(request.body)' if len(endpoint.get('body').get('payload')) > 0 and (header_code != '' or params_code != '') else '\tbody = json.loads(request.body)' if len(endpoint.get('body').get('payload')) > 0 and params_code == '' else ''
 
         defs.append(f"""
 # Name: {endpoint.get('misc').get('name')}
@@ -195,10 +167,11 @@ def VIEWS(app):
 # Params: {', '.join([param[0]+'('+param[1]+')' for param in endpoint.get('params').values() if param[0] and param[1]])}
 # Body: {', '.join([payload[0]+'('+payload[1]+')' for payload in endpoint.get('body').get('payload').values() if payload[0] and payload[1]])}
 {csrf}def {misc.get('token')}(request, *args, **kwargs):
-\treturn JsonResponse({{}})
+{header_code}{params_code}{body_code}
+
+\treturn JsonResponse({{{responses}}})
 """)
 # removed for beta
-# \ttry:{header_code}{param_code}{body_code}
 # \t#### Add Your Logic Here ####
 # \tif request.method == '{req.get('method')}':
 # \t\t\treturn JsonResponse({{
@@ -210,7 +183,7 @@ def VIEWS(app):
     return '\n'.join(defs)
 
 
-def MODELS(app):
+def BASE_MODELS(app):
     app_name =  app.get('name')
     _class = ""
     for model in app.get('models'):
@@ -263,21 +236,22 @@ def MODELS(app):
 from django.db import models
 from django.utils import timezone
 
-# add your models here
 {_class}
 """
 
 # preparing to remove due to beta
 def APP_URLS(app):
     endpoints = app['endpoints']
-    urls = [f"from django.urls import path\n\nfrom clix.views import *\n\nurlpatterns = ["]
+    urls = [
+        f"from django.urls import path\n\nfrom django.contrib import admin\n\nfrom clix.views import *\n\nurlpatterns = [\n\tpath('admin/', admin.site.urls),"]
 
     for endpoint in endpoints:
         urls.append(
-            f"""\tpath('{endpoint.get('request').get('uri')}{'/' if len(endpoint['params']) > 0 else ''}{'/'.join(['<'+param[0]+'>' for param in endpoint['params'].values() if param[0]])}', {endpoint.get('misc').get('token')}),""")
+            f"""\tpath('api/{endpoint.get('request').get('uri')}{'/' if len(endpoint['params']) > 0 else ''}{'/'.join(['<'+param[0]+'>' for param in endpoint['params'].values() if param[0]])}', {endpoint.get('misc').get('token')}),""")
     return '\n'.join(urls) + "\n]"
 
 
+# deprecated at beta
 def ADMIN(app):
     # models = app.get('models')
     # registers = '\n'.join(['admin.site.register(' + model.get('table_name') + ')' for model in models])
